#!/usr/bin/python

# dc3: an experimental, lightweight desktopcouch alternative
# Copyright (C) 2011 Novacut Inc
# 
# This file is part of `dc3`.
# 
# `dc3` is free software: you can redistribute it and/or modify it under the
# terms of the GNU Lesser General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
# 
# `dc3` is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
# details.
# 
# You should have received a copy of the GNU Lesser General Public License along
# with `dc3`.  If not, see <http://www.gnu.org/licenses/>.
#
# Authors:
#   Jason Gerard DeRose <jderose@novacut.com>

"""
Install `dc3`.
"""

from distutils.core import setup
from distutils.cmd import Command
from unittest import TestLoader, TextTestRunner
from doctest import DocTestSuite

import dc3lib


class Test(Command):
    description = 'run unit tests and doc tests'

    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        pynames = [
            'dc3lib',
            'dc3lib.microfiber',
            'dc3lib.tests',
            'dc3lib.tests.test_microfiber',
        ]

        # Add unit-tests:
        loader = TestLoader()
        suite = loader.loadTestsFromNames(pynames)

        # Add doc-tests:
        for name in pynames:
            suite.addTest(DocTestSuite(name))

        # Run the tests:
        runner = TextTestRunner(verbosity=2)
        result = runner.run(suite)
        if not result.wasSuccessful():
            raise SystemExit(2)


setup(
    name='dc3',
    description='an experimental, lightweight desktopcouch alternative',
    url='https://launchpad.net/dc3',
    version=dc3lib.__version__,
    author='Jason Gerard DeRose',
    author_email='jderose@novacut.com',
    license='LGPLv3+',
    packages=['dc3lib', 'dc3lib.tests'],
    scripts=['dc3'],
    data_files=[
        ('share/dbus-1/services', ['org.freedesktop.DC3.service']),
        ('lib/dc3', ['dc3-service']),
        ('share/couchdb/apps/dc3', [
            'app/index.html',
            'app/couch.js',
            'app/base.js',
        ]),
    ],
    cmdclass={'test': Test},
)
